@@ -1,3 +1,17 @@
+use std::rc::Rc;
+
+use itertools::Itertools;
+use num::{Float, ToPrimitive};
+use phf::phf_map;
+
+pub(crate) use self::{
+    binary::binary,
+    comparator::comparator,
+    index::{index, slice},
+    path::{del_paths, get_path, set_path},
+    string::{stringifier, text},
+    unary::unary,
+};
 use crate::{
     compile::compiler::{ArgType, FunctionIdentifier},
     util::make_owned,
@@ -8,19 +22,6 @@ use crate::{
     },
     Array, Value,
 };
-use itertools::Itertools;
-use num::{Float, ToPrimitive};
-use phf::phf_map;
-use std::rc::Rc;
-
-pub(crate) use self::{
-    binary::binary,
-    comparator::comparator,
-    index::{index, slice},
-    path::{del_paths, get_path, set_path},
-    string::{stringifier, text},
-    unary::unary,
-};
 
 mod binary;
 mod comparator;
@@ -185,7 +186,7 @@ fn keys(context: Value) -> Result<Value> {
         Value::Array(arr) => Ok((0..arr.len()).map(Value::number).collect::<Array>().into()),
         Value::Object(obj) => Ok(obj
             .keys()
-            .sorted()
+            .sorted_unstable()
             .map(|k| k.to_string().into())
             .collect::<Array>()
             .into()),
