@@ -1,12 +1,14 @@
+use std::{ops::Range, rc::Rc};
+
+use itertools::{repeat_n, Itertools};
+use num::ToPrimitive;
+
 use crate::{
     util::make_owned,
     value::RcString,
     vm::{error::Result, QueryExecutionError},
     Array, Object, Value,
 };
-use itertools::{repeat_n, Itertools};
-use num::ToPrimitive;
-use std::{ops::Range, rc::Rc};
 
 pub(crate) fn get_path(context: Value, path: Value) -> Result<Value> {
     match path {
@@ -50,7 +52,7 @@ pub(crate) fn del_paths(context: Value, paths: Value) -> Result<Value> {
                 non_slice_len + last_slice
             }
             // We delete from deeper ones so we can raise errors.
-            paths.sort_by_key(|p| std::cmp::Reverse(depth(p)));
+            paths.sort_unstable_by_key(|p| std::cmp::Reverse(depth(p)));
             let mut value = context.clone();
             for path in paths {
                 value =
